
###Introduction

We have collected some word similarity datasets for measuring semantic similarity metrics.

I process them and provide a uniformed framework to evaluate different semantic measures.

###[wordsim353](http://www.cs.technion.ac.il/~gabr/resources/data/wordsim353/)

Lev Finkelstein, Evgeniy Gabrilovich, Yossi Matias, Ehud Rivlin, Zach Solan, Gadi Wolfman, and Eytan Ruppin, "Placing Search in Context: The Concept Revisited", ACM Transactions on Information Systems, 20(1):116-131, January 2002 

###[wordsim353 similarity and relatedness](http://alfonseca.org/eng/research/wordsim353.html)

Eneko Agirre, Enrique Alfonseca, Keith Hall, Jana Kravalova, Marius Pasca, Aitor Soroa, A Study on Similarity and Relatedness Using Distributional and WordNet-based Approaches, In Proceedings of NAACL-HLT 2009.

###[Rubenstein and Goodenough](http://www.cs.cmu.edu/~mfaruqui/word-sim/EN-RG-65.txt)

Herbert Rubenstein and John B. Goodenough. 1965. Contextual correlates of synonymy. Commun. ACM 8, 10 (October 1965), 627-633. DOI=10.1145/365628.365657 

###[Miller and Charles](http://www.cs.cmu.edu/~mfaruqui/word-sim/EN-MC-30.txt)

Miller, George A., and Walter G. Charles. "Contextual correlates of semantic similarity." Language and cognitive processes 6.1 (1991): 1-28.

###[SimLex-999](http://www.cl.cam.ac.uk/~fh295/simlex.html)

SimLex-999: Evaluating Semantic Models with (Genuine) Similarity Estimation. 2014. Felix Hill, Roi Reichart and Anna Korhonen. Preprint pubslished on arXiv. arXiv:1408.3456


NOTE: the folder results contains the experiment results we performed in the word similarity evaluation notebook, while the result original contains the results we got when composing the article. The difference comes from the software version we use and the update of DBpedia data.